package com.sundot.airport.attendance.service;

import com.sundot.airport.attendance.domain.AttendanceCheckRecord;

import java.util.List;

/**
 * 打卡记录Service接口
 *
 * @author wangchong
 * @date 2025-07-10
 */
public interface IAttendanceCheckRecordService {
    /**
     * 查询打卡记录
     *
     * @param id 打卡记录主键
     * @return 打卡记录
     */
    public AttendanceCheckRecord selectAttendanceCheckRecordById(Long id);

    /**
     * 查询打卡记录列表
     *
     * @param attendanceCheckRecord 打卡记录
     * @return 打卡记录集合
     */
    public List<AttendanceCheckRecord> selectAttendanceCheckRecordList(AttendanceCheckRecord attendanceCheckRecord);

    /**
     * 新增打卡记录
     *
     * @param attendanceCheckRecord 打卡记录
     * @return 结果
     */
    public int insertAttendanceCheckRecord(AttendanceCheckRecord attendanceCheckRecord);

    /**
     * 修改打卡记录
     *
     * @param attendanceCheckRecord 打卡记录
     * @return 结果
     */
    public int updateAttendanceCheckRecord(AttendanceCheckRecord attendanceCheckRecord);

    /**
     * 批量删除打卡记录
     *
     * @param ids 需要删除的打卡记录主键集合
     * @return 结果
     */
    public int deleteAttendanceCheckRecordByIds(Long[] ids);

    /**
     * 删除打卡记录信息
     *
     * @param id 打卡记录主键
     * @return 结果
     */
    public int deleteAttendanceCheckRecordById(Long id);
}
